@@ -5,5 +5,8 @@
 #define RTRN_ERR_CMDLINE 1
 /* an internal error, should no be possible */
 #define RTRN_ERR_INTERNAL 2
+#define RTRN_ERR_PATHTOOLONG 4
+#define RTRN_ERR_BADCWD 8
+#define RTRN_ERR_FILE 16
 
 #endif /* __RETURNCODES_H__ */
